==> ah-formbuilder-1.0.61.tgz: package/es/utils/predefined-values/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from "react";
import Button from "@material-ui/core/Button";
import Dialog from "@material-ui/core/Dialog";
import DialogActions from "@material-ui/core/DialogActions";
import DialogContent from "@material-ui/core/DialogContent";
import Toolbar from "@material-ui/core/Toolbar";
import Typography from "@material-ui/core/Typography";
import IconButton from "@material-ui/core/IconButton";
import Paper from "@material-ui/core/Paper";
import Draggable from "react-draggable";
import AppBar from "@material-ui/core/AppBar";
import List from "@material-ui/core/List";
import ListItem from "@material-ui/core/ListItem";
import ListItemText from "@material-ui/core/ListItemText";
import ListItemSecondaryAction from "@material-ui/core/ListItemSecondaryAction";
import { Grid, Tooltip } from "@material-ui/core";
import Snackbar from "@material-ui/core/Snackbar";
import DeleteIcon from "@material-ui/icons/Delete";
import AddIcon from "@material-ui/icons/Add";
import CloseIcon from "@material-ui/icons/Close";
import DoneIcon from "@material-ui/icons/Done";
import _ from "lodash";
import axios from "axios";
import { connect } from "react-redux";
import "./style.scss";
import NewCategory from "./NewCategory";
import { addCategory as _addCategory, updateCategoryOptions as _updateCategoryOptions } from "../../actions/predefinedActions";
import { stringToSlug } from "../helpers";
import NewOption from "./NewOption";
import FormHelperText from "@material-ui/core/FormHelperText";
var addLabel = {
  en: "Add Predefined Values",
  ar: "أضف قيمًا محددة مسبقًا"
};
var categoryLabel = {
  en: "Category",
  ar: "الفئة"
};
var cancelLabel = {
  en: "Cancel",
  ar: "إلغاء"
};
var insertLabel = {
  en: "Insert Choices",
  ar: "أدخل الاختيارات"
};
var noPredefinedLabel = {
  en: "There are no predefined categories available.",
  ar: "لا توجد فئات محددة مسبقا متاحة"
};
var noOptionsLabel = {
  en: "No options available",
  ar: "لا توجد خيارات متاحة"
};
var createNewOptionsLabel = {
  en: "Start Creating new options",
  ar: "ابدأ في إنشاء خيارات جديدة"
};
var viewOptionsLabel = {
  en: "Select a category to view its options",
  ar: "حدد فئة لعرض خياراتها"
};
var newCategoryLabel = {
  en: "New category successfully added.",
  ar: "تمت إضافة فئة جديدة بنجاح"
};
var divisionLabel = {
  en: "Divisions",
  ar: "الانقسامات"
};
var jobTitleLabel = {
  en: "Job Title",
  ar: "مسمى وظيفي"
};
var locationLabel = {
  en: "Locations",
  ar: "المواقع"
};

function PaperComponent(props) {
  return /*#__PURE__*/React.createElement(Draggable, {
    handle: "#draggable-dialog-title",
    cancel: '[class*="MuiDialogContent-root"]'
  }, /*#__PURE__*/React.createElement(Paper, props));
}

var PredefinedValues = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(PredefinedValues, _React$Component);

  function PredefinedValues(props) {
    var _this;

    _this = _React$Component.call(this, props) || this;

    _defineProperty(_assertThisInitialized(_this), "handleAddCategoryMsgClose", function () {
      _this.setState({
        showAddCategoryMsg: false
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleClickOpen", function () {
      _this.setState({
        open: true
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleClose", function () {
      _this.setState({
        open: false
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleInsert", function () {
      if (_this.state.activeCategory) {
        _this.props.insertChoices(_this.state.activeCategory);

        _this.handleClose();
      } else {
        _this.setState({
          insertError: {
            en: "Select a category to insert options",
            ar: "حدد فئة لعرض خياراتها"
          }
        });
      }
    });

    _defineProperty(_assertThisInitialized(_this), "enableCategory", function (category) {
      _this.setState({
        activeCategory: category,
        insertError: null
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleAddCategoryOpen", function () {
      _this.setState({
        addCategory: true
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleAddCategoryClose", function () {
      _this.setState({
        addCategory: false
      });
    });

    _defineProperty(_assertThisInitialized(_this), "saveNewCategory", function (categoryName) {
      var slug = stringToSlug(categoryName);
      var data = {
        options: [],
        label: categoryName
      };
      axios.post(_this.props.predefinedEndpoint, {
        name: categoryName,
        slug: slug,
        isPublic: true
      }).then(function (res) {
        _this.props.addCategory(res.data);

        _this.setState({
          addCategory: false,
          showAddCategoryMsg: true
        });
      });
    });

    _defineProperty(_assertThisInitialized(_this), "saveNewCategoryOption", function (name, value) {
      axios.post(_this.props.predefinedEndpoint + "/" + _this.state.activeCategory.id + "/options", {
        name: name,
        value: value
      }).then(function (res) {
        _this.props.updateCategoryOptions(res.data.options, _this.state.activeCategory.slug);

        _this.setState({
          activeCategory: _extends({}, _this.state.activeCategory, {
            options: res.data.options
          })
        });
      });
    });

    _defineProperty(_assertThisInitialized(_this), "deleteOption", function (option) {
      axios["delete"](_this.props.predefinedEndpoint + "/" + _this.state.activeCategory.id + "/options/" + option.id).then(function (res) {
        _this.props.updateCategoryOptions(res.data.options, _this.state.activeCategory.slug);

        _this.setState({
          activeCategory: _extends({}, _this.state.activeCategory, {
            options: res.data.options
          })
        });
      });
    });

    _defineProperty(_assertThisInitialized(_this), "renderAddCategory", function () {
      if (_this.state.addCategory) {
        return /*#__PURE__*/React.createElement(NewCategory, {
          currentLang: _this.props.currentLang,
          names: _.map(_this.props.predefined, function (item) {
            return item.name.toLowerCase();
          }),
          saveNewCategory: _this.saveNewCategory,
          handleAddCategoryClose: _this.handleAddCategoryClose
        });
      }
    });

    _defineProperty(_assertThisInitialized(_this), "renderAddOption", function () {
      if (_this.state.activeCategory && !_this.state.activeCategory.is_secure) {
        return /*#__PURE__*/React.createElement(NewOption, {
          saveNewCategoryOption: _this.saveNewCategoryOption,
          options: _this.state.activeCategory.options
        });
      }
    });

    _defineProperty(_assertThisInitialized(_this), "renderCategories", function () {
      if (_.size(_this.props.predefined)) {
        return _.map(_this.props.predefined, function (category) {
          if (category.is_public) {
            if (category.name === "Divisions") {
              return /*#__PURE__*/React.createElement(ListItem, {
                key: "category-" + category.slug,
                button: true,
                selected: _this.state.activeCategory && _this.state.activeCategory.slug === category.slug,
                onClick: function onClick(e) {
                  return _this.enableCategory(category);
                }
              }, /*#__PURE__*/React.createElement(ListItemText, {
                primary: divisionLabel[_this.props.currentLang]
              }));
            } else if (category.name === "Job Titles") {
              return /*#__PURE__*/React.createElement(ListItem, {
                key: "category-" + category.slug,
                button: true,
                selected: _this.state.activeCategory && _this.state.activeCategory.slug === category.slug,
                onClick: function onClick(e) {
                  return _this.enableCategory(category);
                }
              }, /*#__PURE__*/React.createElement(ListItemText, {
                primary: jobTitleLabel[_this.props.currentLang]
              }));
            } else if (category.name === "Locations") {
              return /*#__PURE__*/React.createElement(ListItem, {
                key: "category-" + category.slug,
                button: true,
                selected: _this.state.activeCategory && _this.state.activeCategory.slug === category.slug,
                onClick: function onClick(e) {
                  return _this.enableCategory(category);
                }
              }, /*#__PURE__*/React.createElement(ListItemText, {
                primary: locationLabel[_this.props.currentLang]
              }));
            } else {
              return /*#__PURE__*/React.createElement(ListItem, {
                key: "category-" + category.slug,
                button: true,
                selected: _this.state.activeCategory && _this.state.activeCategory.slug === category.slug,
                onClick: function onClick(e) {
                  return _this.enableCategory(category);
                }
              }, /*#__PURE__*/React.createElement(ListItemText, {
                primary: category.name
              }));
            }
          }
        });
      } else {
        return /*#__PURE__*/React.createElement("div", null, noPredefinedLabel[_this.props.currentLang]);
      }
    });

    _defineProperty(_assertThisInitialized(_this), "renderCategoryOptions", function () {
      if (_this.state.activeCategory) {
        if (_this.state.activeCategory.options && _this.state.activeCategory.options.length) {
          var options = _this.state.activeCategory.options;
          var labelProp = "name";
          var valueProp = "value";
          return options.map(function (option) {
            return /*#__PURE__*/React.createElement(ListItem, {
              key: option.id
            }, /*#__PURE__*/React.createElement(ListItemText, {
              primary: option[labelProp]
            }), !_this.state.activeCategory.is_secure ? /*#__PURE__*/React.createElement(ListItemSecondaryAction, null, /*#__PURE__*/React.createElement(IconButton, {
              edge: "end",
              "aria-label": "delete",
              onClick: function onClick(e) {
                return _this.deleteOption(option);
              }
            }, /*#__PURE__*/React.createElement(DeleteIcon, null))) : "");
          });
        } else if (_this.state.activeCategory.is_secure) {
          return /*#__PURE__*/React.createElement("span", null, noOptionsLabel[_this.props.currentLang]);
        } else {
          return /*#__PURE__*/React.createElement("span", null, createNewOptionsLabel[_this.props.currentLang]);
        }
      } else {
        return /*#__PURE__*/React.createElement("span", null, viewOptionsLabel[_this.props.currentLang]);
      }
    });

    var active = null;

    if (props.selected) {
      for (var i = 0; i < props.predefined.length; i++) {
        if (props.predefined[i].is_public && props.predefined[i].id === _this.props.selected) {
          active = props.predefined[i];
          break;
        }
      }
    }

    _this.state = {
      open: false,
      activeCategory: active,
      addCategory: false,
      newCategoryName: "",
      showAddCategoryMsg: false,
      insertError: null
    };
    return _this;
  }

  var _proto = PredefinedValues.prototype;

  _proto.render = function render() {
    return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("div", {
      className: "ahfb-width-full ahfb-text-right"
    }, /*#__PURE__*/React.createElement(Button, {
      onClick: this.handleClickOpen
    }, this.state.activeCategory && this.state.activeCategory.isPublic ? /*#__PURE__*/React.createElement(DoneIcon, null) : "", " ", addLabel[this.props.currentLang])), /*#__PURE__*/React.createElement(Dialog, {
      open: this.state.open,
      onClose: this.handleClose,
      PaperComponent: PaperComponent,
      "aria-labelledby": "draggable-dialog-title",
      maxWidth: "xl"
    }, /*#__PURE__*/React.createElement(AppBar, {
      className: "ahfb-position-relative"
    }, /*#__PURE__*/React.createElement(Toolbar, null, /*#__PURE__*/React.createElement(Typography, {
      variant: "h6"
    }, addLabel[this.props.currentLang]), /*#__PURE__*/React.createElement(IconButton, {
      className: "ahfb-position-absolute ahfb-shift-right",
      color: "inherit",
      onClick: this.handleClose,
      "aria-label": "close"
    }, /*#__PURE__*/React.createElement(CloseIcon, null)))), /*#__PURE__*/React.createElement(DialogContent, null, /*#__PURE__*/React.createElement(Grid, {
      container: true,
      className: "ahfb-dialog-content-root"
    }, /*#__PURE__*/React.createElement(Grid, {
      item: true,
      xs: 5,
      className: "ahfb-pr-1 ahfb-categories-list-container"
    }, /*#__PURE__*/React.createElement("div", {
      className: "ahfb-position-relative"
    }, /*#__PURE__*/React.createElement(Typography, {
      variant: "h6",
      component: "h6",
      className: "ahfb-categories-add-heading"
    }, /*#__PURE__*/React.createElement("span", null, categoryLabel[this.props.currentLang]), /*#__PURE__*/React.createElement(Tooltip, {
      title: "Add a new category"
    }, /*#__PURE__*/React.createElement(IconButton, {
      onClick: this.handleAddCategoryOpen,
      className: "ahfb-categories-add-icon " + (this.props.currentLang === "ar" ? "ahfb-width-50" : "")
    }, /*#__PURE__*/React.createElement(AddIcon, null))))), this.renderAddCategory(), /*#__PURE__*/React.createElement(List, {
      className: "ahfb-categories-list"
    }, this.renderCategories())), /*#__PURE__*/React.createElement(Grid, {
      item: true,
      xs: 7
    }, /*#__PURE__*/React.createElement(List, null, this.renderCategoryOptions(), this.renderAddOption()))), !!this.state.insertError ? /*#__PURE__*/React.createElement(FormHelperText, {
      error: true
    }, this.state.insertError[this.props.currentLang]) : ""), /*#__PURE__*/React.createElement(DialogActions, null, /*#__PURE__*/React.createElement(Button, {
      autoFocus: true,
      onClick: this.handleClose,
      variant: "outlined"
    }, cancelLabel[this.props.currentLang]), /*#__PURE__*/React.createElement(Button, {
      onClick: this.handleInsert,
      variant: "contained"
    }, insertLabel[this.props.currentLang]))), /*#__PURE__*/React.createElement(Snackbar, {
      anchorOrigin: {
        vertical: "bottom",
        horizontal: "left"
      },
      open: this.state.showAddCategoryMsg,
      autoHideDuration: 6000,
      onClose: this.handleAddCategoryMsgClose,
      message: newCategoryLabel[this.props.currentLang],
      action: /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(IconButton, {
        size: "small",
        "aria-label": "close",
        color: "inherit",
        onClick: this.handleAddCategoryMsgClose
      }, /*#__PURE__*/React.createElement(CloseIcon, {
        fontSize: "small"
      })))
    }));
  };

  return PredefinedValues;
}(React.Component);

var mapStateToProps = function mapStateToProps(state) {
  return {
    predefined: state.form.predefined,
    predefinedEndpoint: state.form.predefinedEndpoint,
    currentLang: state.form.currentLang
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    addCategory: function addCategory(data) {
      return dispatch(_addCategory(data));
    },
    updateCategoryOptions: function updateCategoryOptions(data, slug) {
      return dispatch(_updateCategoryOptions(data, slug));
    }
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(PredefinedValues);

==> ah-formbuilder-1.2.6.tgz: package/es/utils/predefined-values/index.js <==
function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } return n; }, _extends.apply(null, arguments); }
function _inheritsLoose(t, o) { t.prototype = Object.create(o.prototype), t.prototype.constructor = t, _setPrototypeOf(t, o); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
function _defineProperty(e, r, t) { return (r = _toPropertyKey(r)) in e ? Object.defineProperty(e, r, { value: t, enumerable: !0, configurable: !0, writable: !0 }) : e[r] = t, e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == typeof i ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != typeof t || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != typeof i) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
import React from "react";
import Button from "@material-ui/core/Button";
import Dialog from "@material-ui/core/Dialog";
import DialogActions from "@material-ui/core/DialogActions";
import DialogContent from "@material-ui/core/DialogContent";
import Toolbar from "@material-ui/core/Toolbar";
import Typography from "@material-ui/core/Typography";
import IconButton from "@material-ui/core/IconButton";
import Paper from "@material-ui/core/Paper";
import Draggable from "react-draggable";
import AppBar from "@material-ui/core/AppBar";
import List from "@material-ui/core/List";
import ListItem from "@material-ui/core/ListItem";
import ListItemText from "@material-ui/core/ListItemText";
import ListItemSecondaryAction from "@material-ui/core/ListItemSecondaryAction";
import { Grid, Tooltip } from "@material-ui/core";
import Snackbar from "@material-ui/core/Snackbar";
import DeleteIcon from "@material-ui/icons/Delete";
import AddIcon from "@material-ui/icons/Add";
import CloseIcon from "@material-ui/icons/Close";
import DoneIcon from "@material-ui/icons/Done";
import _ from "lodash";
import axios from "axios";
import { connect } from "react-redux";
import "./style.scss";
import NewCategory from "./NewCategory";
import { addCategory as _addCategory, updateCategoryOptions as _updateCategoryOptions } from "../../actions/predefinedActions";
import { stringToSlug } from "../helpers";
import NewOption from "./NewOption";
import FormHelperText from "@material-ui/core/FormHelperText";
var addLabel = {
  en: "Add Predefined Values",
  ar: "أضف قيمًا محددة مسبقًا"
};
var categoryLabel = {
  en: "Category",
  ar: "الفئة"
};
var cancelLabel = {
  en: "Cancel",
  ar: "إلغاء"
};
var insertLabel = {
  en: "Insert Choices",
  ar: "أدخل الاختيارات"
};
var noPredefinedLabel = {
  en: "There are no predefined categories available.",
  ar: "لا توجد فئات محددة مسبقا متاحة"
};
var noOptionsLabel = {
  en: "No options available",
  ar: "لا توجد خيارات متاحة"
};
var createNewOptionsLabel = {
  en: "Start Creating new options",
  ar: "ابدأ في إنشاء خيارات جديدة"
};
var viewOptionsLabel = {
  en: "Select a category to view its options",
  ar: "حدد فئة لعرض خياراتها"
};
var newCategoryLabel = {
  en: "New category successfully added.",
  ar: "تمت إضافة فئة جديدة بنجاح"
};
var divisionLabel = {
  en: "Divisions",
  ar: "الانقسامات"
};
var jobTitleLabel = {
  en: "Job Title",
  ar: "مسمى وظيفي"
};
var locationLabel = {
  en: "Locations",
  ar: "المواقع"
};
function PaperComponent(props) {
  return /*#__PURE__*/React.createElement(Draggable, {
    handle: "#draggable-dialog-title",
    cancel: '[class*="MuiDialogContent-root"]'
  }, /*#__PURE__*/React.createElement(Paper, props));
}
var PredefinedValues = /*#__PURE__*/function (_React$Component) {
  function PredefinedValues(props) {
    var _this;
    _this = _React$Component.call(this, props) || this;
    _defineProperty(_this, "handleAddCategoryMsgClose", function () {
      _this.setState({
        showAddCategoryMsg: false
      });
    });
    _defineProperty(_this, "handleClickOpen", function () {
      _this.setState({
        open: true
      });
    });
    _defineProperty(_this, "handleClose", function () {
      _this.setState({
        open: false
      });
    });
    _defineProperty(_this, "handleInsert", function () {
      if (_this.state.activeCategory) {
        _this.props.insertChoices(_this.state.activeCategory);
        _this.handleClose();
      } else {
        _this.setState({
          insertError: {
            en: "Select a category to insert options",
            ar: "حدد فئة لعرض خياراتها"
          }
        });
      }
    });
    _defineProperty(_this, "enableCategory", function (category) {
      _this.setState({
        activeCategory: category,
        insertError: null
      });
    });
    _defineProperty(_this, "handleAddCategoryOpen", function () {
      _this.setState({
        addCategory: true
      });
    });
    _defineProperty(_this, "handleAddCategoryClose", function () {
      _this.setState({
        addCategory: false
      });
    });
    _defineProperty(_this, "saveNewCategory", function (categoryName) {
      var slug = stringToSlug(categoryName);
      var data = {
        options: [],
        label: categoryName
      };
      axios.post(_this.props.predefinedEndpoint, {
        name: categoryName,
        slug: slug,
        isPublic: true
      }).then(function (res) {
        _this.props.addCategory(res.data);
        _this.setState({
          addCategory: false,
          showAddCategoryMsg: true
        });
      });
    });
    _defineProperty(_this, "saveNewCategoryOption", function (name, value) {
      axios.post(_this.props.predefinedEndpoint + "/" + _this.state.activeCategory.id + "/options", {
        name: name,
        value: value
      }).then(function (res) {
        _this.props.updateCategoryOptions(res.data.options, _this.state.activeCategory.slug);
        _this.setState({
          activeCategory: _extends({}, _this.state.activeCategory, {
            options: res.data.options
          })
        });
      });
    });
    _defineProperty(_this, "deleteOption", function (option) {
      axios["delete"](_this.props.predefinedEndpoint + "/" + _this.state.activeCategory.id + "/options/" + option.id).then(function (res) {
        _this.props.updateCategoryOptions(res.data.options, _this.state.activeCategory.slug);
        _this.setState({
          activeCategory: _extends({}, _this.state.activeCategory, {
            options: res.data.options
          })
        });
      });
    });
    _defineProperty(_this, "renderAddCategory", function () {
      if (_this.state.addCategory) {
        return /*#__PURE__*/React.createElement(NewCategory, {
          currentLang: _this.props.currentLang,
          names: _.map(_this.props.predefined, function (item) {
            return item.name.toLowerCase();
          }),
          saveNewCategory: _this.saveNewCategory,
          handleAddCategoryClose: _this.handleAddCategoryClose
        });
      }
    });
    _defineProperty(_this, "renderAddOption", function () {
      if (_this.state.activeCategory && !_this.state.activeCategory.is_secure) {
        return /*#__PURE__*/React.createElement(NewOption, {
          saveNewCategoryOption: _this.saveNewCategoryOption,
          options: _this.state.activeCategory.options
        });
      }
    });
    _defineProperty(_this, "renderCategories", function () {
      if (_.size(_this.props.predefined)) {
        return _.map(_this.props.predefined, function (category) {
          if (category.is_public) {
            if (category.name === "Divisions") {
              return /*#__PURE__*/React.createElement(ListItem, {
                key: "category-" + category.slug,
                button: true,
                selected: _this.state.activeCategory && _this.state.activeCategory.slug === category.slug,
                onClick: function onClick(e) {
                  return _this.enableCategory(category);
                }
              }, /*#__PURE__*/React.createElement(ListItemText, {
                primary: divisionLabel[_this.props.currentLang]
              }));
            } else if (category.name === "Job Titles") {
              return /*#__PURE__*/React.createElement(ListItem, {
                key: "category-" + category.slug,
                button: true,
                selected: _this.state.activeCategory && _this.state.activeCategory.slug === category.slug,
                onClick: function onClick(e) {
                  return _this.enableCategory(category);
                }
              }, /*#__PURE__*/React.createElement(ListItemText, {
                primary: jobTitleLabel[_this.props.currentLang]
              }));
            } else if (category.name === "Locations") {
              return /*#__PURE__*/React.createElement(ListItem, {
                key: "category-" + category.slug,
                button: true,
                selected: _this.state.activeCategory && _this.state.activeCategory.slug === category.slug,
                onClick: function onClick(e) {
                  return _this.enableCategory(category);
                }
              }, /*#__PURE__*/React.createElement(ListItemText, {
                primary: locationLabel[_this.props.currentLang]
              }));
            } else {
              return /*#__PURE__*/React.createElement(ListItem, {
                key: "category-" + category.slug,
                button: true,
                selected: _this.state.activeCategory && _this.state.activeCategory.slug === category.slug,
                onClick: function onClick(e) {
                  return _this.enableCategory(category);
                }
              }, /*#__PURE__*/React.createElement(ListItemText, {
                primary: category.name
              }));
            }
          }
        });
      } else {
        return /*#__PURE__*/React.createElement("div", null, noPredefinedLabel[_this.props.currentLang]);
      }
    });
    _defineProperty(_this, "renderCategoryOptions", function () {
      if (_this.state.activeCategory) {
        if (_this.state.activeCategory.options && _this.state.activeCategory.options.length) {
          var options = _this.state.activeCategory.options;
          var labelProp = "name";
          var valueProp = "value";
          return options.map(function (option) {
            return /*#__PURE__*/React.createElement(ListItem, {
              key: option.id
            }, /*#__PURE__*/React.createElement(ListItemText, {
              primary: option[labelProp]
            }), !_this.state.activeCategory.is_secure ? /*#__PURE__*/React.createElement(ListItemSecondaryAction, null, /*#__PURE__*/React.createElement(IconButton, {
              edge: "end",
              "aria-label": "delete",
              onClick: function onClick(e) {
                return _this.deleteOption(option);
              }
            }, /*#__PURE__*/React.createElement(DeleteIcon, null))) : "");
          });
        } else if (_this.state.activeCategory.is_secure) {
          return /*#__PURE__*/React.createElement("span", null, noOptionsLabel[_this.props.currentLang]);
        } else {
          return /*#__PURE__*/React.createElement("span", null, createNewOptionsLabel[_this.props.currentLang]);
        }
      } else {
        return /*#__PURE__*/React.createElement("span", null, viewOptionsLabel[_this.props.currentLang]);
      }
    });
    var active = null;
    if (props.selected) {
      for (var i = 0; i < props.predefined.length; i++) {
        if (props.predefined[i].is_public && props.predefined[i].id === _this.props.selected) {
          active = props.predefined[i];
          break;
        }
      }
    }
    _this.state = {
      open: false,
      activeCategory: active,
      addCategory: false,
      newCategoryName: "",
      showAddCategoryMsg: false,
      insertError: null
    };
    return _this;
  }
  _inheritsLoose(PredefinedValues, _React$Component);
  var _proto = PredefinedValues.prototype;
  _proto.render = function render() {
    return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("div", {
      className: "ahfb-width-full ahfb-text-right"
    }, /*#__PURE__*/React.createElement(Button, {
      onClick: this.handleClickOpen
    }, this.state.activeCategory && this.state.activeCategory.isPublic ? /*#__PURE__*/React.createElement(DoneIcon, null) : "", " ", addLabel[this.props.currentLang])), /*#__PURE__*/React.createElement(Dialog, {
      open: this.state.open,
      onClose: this.handleClose,
      PaperComponent: PaperComponent,
      "aria-labelledby": "draggable-dialog-title",
      maxWidth: "xl"
    }, /*#__PURE__*/React.createElement(AppBar, {
      className: "ahfb-position-relative"
    }, /*#__PURE__*/React.createElement(Toolbar, null, /*#__PURE__*/React.createElement(Typography, {
      variant: "h6"
    }, addLabel[this.props.currentLang]), /*#__PURE__*/React.createElement(IconButton, {
      className: "ahfb-position-absolute ahfb-shift-right",
      color: "inherit",
      onClick: this.handleClose,
      "aria-label": "close"
    }, /*#__PURE__*/React.createElement(CloseIcon, null)))), /*#__PURE__*/React.createElement(DialogContent, null, /*#__PURE__*/React.createElement(Grid, {
      container: true,
      className: "ahfb-dialog-content-root"
    }, /*#__PURE__*/React.createElement(Grid, {
      item: true,
      xs: 5,
      className: "ahfb-pr-1 ahfb-categories-list-container"
    }, /*#__PURE__*/React.createElement("div", {
      className: "ahfb-position-relative"
    }, /*#__PURE__*/React.createElement(Typography, {
      variant: "h6",
      component: "h6",
      className: "ahfb-categories-add-heading"
    }, /*#__PURE__*/React.createElement("span", null, categoryLabel[this.props.currentLang]), /*#__PURE__*/React.createElement(Tooltip, {
      title: "Add a new category"
    }, /*#__PURE__*/React.createElement(IconButton, {
      onClick: this.handleAddCategoryOpen,
      className: "ahfb-categories-add-icon " + (this.props.currentLang === "ar" ? "ahfb-width-50" : "")
    }, /*#__PURE__*/React.createElement(AddIcon, null))))), this.renderAddCategory(), /*#__PURE__*/React.createElement(List, {
      className: "ahfb-categories-list"
    }, this.renderCategories())), /*#__PURE__*/React.createElement(Grid, {
      item: true,
      xs: 7
    }, /*#__PURE__*/React.createElement(List, null, this.renderCategoryOptions(), this.renderAddOption()))), !!this.state.insertError ? /*#__PURE__*/React.createElement(FormHelperText, {
      error: true
    }, this.state.insertError[this.props.currentLang]) : ""), /*#__PURE__*/React.createElement(DialogActions, null, /*#__PURE__*/React.createElement(Button, {
      autoFocus: true,
      onClick: this.handleClose,
      variant: "outlined"
    }, cancelLabel[this.props.currentLang]), /*#__PURE__*/React.createElement(Button, {
      onClick: this.handleInsert,
      variant: "contained"
    }, insertLabel[this.props.currentLang]))), /*#__PURE__*/React.createElement(Snackbar, {
      anchorOrigin: {
        vertical: "bottom",
        horizontal: "left"
      },
      open: this.state.showAddCategoryMsg,
      autoHideDuration: 6000,
      onClose: this.handleAddCategoryMsgClose,
      message: newCategoryLabel[this.props.currentLang],
      action: /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(IconButton, {
        size: "small",
        "aria-label": "close",
        color: "inherit",
        onClick: this.handleAddCategoryMsgClose
      }, /*#__PURE__*/React.createElement(CloseIcon, {
        fontSize: "small"
      })))
    }));
  };
  return PredefinedValues;
}(React.Component);
var mapStateToProps = function mapStateToProps(state) {
  return {
    predefined: state.form.predefined,
    predefinedEndpoint: state.form.predefinedEndpoint,
    currentLang: state.form.currentLang
  };
};
var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    addCategory: function addCategory(data) {
      return dispatch(_addCategory(data));
    },
    updateCategoryOptions: function updateCategoryOptions(data, slug) {
      return dispatch(_updateCategoryOptions(data, slug));
    }
  };
};
export default connect(mapStateToProps, mapDispatchToProps)(PredefinedValues);
